Welcome to mirror list, hosted at ThFree Co, Russian Federation.

git.blender.org/blender.git - Unnamed repository; edit this file 'description' to name the repository.
summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorClément Foucault <foucault.clem@gmail.com>2021-11-01 14:15:09 +0300
committerClément Foucault <foucault.clem@gmail.com>2021-11-01 14:15:09 +0300
commit3f0991266f418e1b256d8157f83fe2ba3c05014d (patch)
tree38c0c8d0cee18d0d8e7f297c6ce5cf4d210bec9e /intern/cycles/device/hip
parenta96b2f39b82373d05f543bba325b2dd21baabf63 (diff)
parent81bd49d4fea41f6e569f3778724b33f15e95f853 (diff)
Merge branch 'blender-v3.0-release'
Diffstat (limited to 'intern/cycles/device/hip')
-rw-r--r--intern/cycles/device/hip/device_impl.cpp12
1 files changed, 8 insertions, 4 deletions
diff --git a/intern/cycles/device/hip/device_impl.cpp b/intern/cycles/device/hip/device_impl.cpp
index 31b7b07383b..1ea387513d5 100644
--- a/intern/cycles/device/hip/device_impl.cpp
+++ b/intern/cycles/device/hip/device_impl.cpp
@@ -360,7 +360,9 @@ string HIPDevice::compile_kernel(const uint kernel_features,
source_path.c_str(),
fatbin.c_str());
- printf("Compiling HIP kernel ...\n%s\n", command.c_str());
+ printf("Compiling %sHIP kernel ...\n%s\n",
+ (use_adaptive_compilation()) ? "adaptive " : "",
+ command.c_str());
# ifdef _WIN32
command = "call " + command;
@@ -387,13 +389,15 @@ string HIPDevice::compile_kernel(const uint kernel_features,
bool HIPDevice::load_kernels(const uint kernel_features)
{
/* TODO(sergey): Support kernels re-load for HIP devices.
*
* Currently re-loading kernel will invalidate memory pointers,
- * causing problems in hipCtxSynchronize.
+ * causing problems in cuCtxSynchronize.
*/
if (hipModule) {
- VLOG(1) << "Skipping kernel reload, not currently supported.";
+ if (use_adaptive_compilation()) {
+ VLOG(1) << "Skipping HIP kernel reload for adaptive compilation, not currently supported.";
+ }
return true;
}
@@ -387,13 +389,15 @@ string HIPDevice::compile_kernel(const uint kernel_features,
bool HIPDevice::load_kernels(const uint kernel_features)
{
- /* TODO(sergey): Support kernels re-load for HIP devices.
+ /* TODO(sergey): Support kernels re-load for CUDA devices adaptive compile.
*
* Currently re-loading kernel will invalidate memory pointers,